Python Protocol definitions for Hedgehog
========================================

Master: |travis-master|_ |coveralls-master|_

Develop: |travis-develop|_ |coveralls-develop|_

.. |travis-master| image:: https://travis-ci.org/PRIArobotics/HedgehogProtocol.svg?branch=master
.. _travis-master: https://travis-ci.org/PRIArobotics/HedgehogProtocol
.. |coveralls-master| image:: https://coveralls.io/repos/github/PRIArobotics/HedgehogProtocol/badge.svg?branch=master
.. _coveralls-master: https://coveralls.io/github/PRIArobotics/HedgehogProtocol?branch=master
.. |travis-develop| image:: https://travis-ci.org/PRIArobotics/HedgehogProtocol.svg?branch=develop
.. _travis-develop: https://travis-ci.org/PRIArobotics/HedgehogProtocol
.. |coveralls-develop| image:: https://coveralls.io/repos/github/PRIArobotics/HedgehogProtocol/badge.svg?branch=develop
.. _coveralls-develop: https://coveralls.io/github/PRIArobotics/HedgehogProtocol?branch=develop

----

This project contains the Python implementation of protocol definitions for the Hedgehog Educational Robotics Controller.
